// Copyright 2007 - 2021, Alan Antonuk and the rabbitmq-c contributors.
// SPDX-License-Identifier: mit

/** @file amqp_framing.h */
#ifndef AMQP_FRAMING_H
#define AMQP_FRAMING_H

#ifdef _MSC_VER
#   pragma message("warning: amqp_framing.h is deprecated, use rabbitmq-c/framing.h instead.")
#else
#   warning "amqp_framing.h is deprecated, use rabbitmq-c/framing.h instead."
#endif

#include <rabbitmq-c/framing.h>

#endif /* AMQP_FRAMING_H */
